@@ -1,4 +1,4 @@
-"""Wrappers around the logging module"""
+"""Wrappers around the logging module."""
 
 from __future__ import absolute_import
 
@@ -10,19 +10,22 @@ from colorlog.colorlog import ColoredFormatter
 BASIC_FORMAT = "%(log_color)s%(levelname)s%(reset)s:%(name)s:%(message)s"
 
 
-def basicConfig(*args, **kwargs):
-    """This calls basicConfig() and then overrides the formatter it creates"""
-    logging.basicConfig(*args, **kwargs)
+def basicConfig(**kwargs):
+    """Call ``logging.basicConfig`` and override the formatter it creates."""
+    logging.basicConfig(**kwargs)
     logging._acquireLock()
     try:
         stream = logging.root.handlers[0]
-        stream.setFormatter(ColoredFormatter(BASIC_FORMAT))
+        stream.setFormatter(
+            ColoredFormatter(
+                format=kwargs.get('format', BASIC_FORMAT),
+                datefmt=kwargs.get('datefmt', None)))
     finally:
         logging._releaseLock()
 
 
 def ensure_configured(func):
-    """This ensures basicConfig is called if no handlers exist"""
+    """Modify a function to call ``basicConfig`` first if no handlers exist."""
     @functools.wraps(func)
     def wrapper(*args, **kwargs):
         if len(logging.root.handlers) == 0:
